"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const device_manager_1 = require("../lib/device-manager");
const ns_capabilities_1 = require("../lib/ns-capabilities");
const mobile_devices_controller_1 = require("mobile-devices-controller");
const chai_1 = require("chai");
const index_1 = require("../index");
const appium_server_1 = require("../lib/appium-server");
const appium_driver_1 = require("../lib/appium-driver");
const capabilities_helper_1 = require("../lib/capabilities-helper");
const androidApp = "~/git/out/QSF-release.apk";
const iosApp = "/Users/tsenov/git/nativescript-sdk-examples-ng/platforms/ios/build/emulator/nativescriptsdkexamplesng.app";
describe("android devices", () => {
    let deviceManager;
    const appiumArgs = index_1.nsCapabilities;
    before("Init: DeviceManager", () => {
        mobile_devices_controller_1.DeviceController.killAll(mobile_devices_controller_1.DeviceType.EMULATOR);
        deviceManager = new device_manager_1.DeviceManager();
        appiumArgs.extend({ appiumCaps: { platformName: mobile_devices_controller_1.Platform.ANDROID, fullReset: false } });
    });
    after("Kill all emulators", () => {
        mobile_devices_controller_1.DeviceController.killAll(mobile_devices_controller_1.DeviceType.EMULATOR);
    });
    it("Start emulator", () => __awaiter(this, void 0, void 0, function* () {
        const device = yield deviceManager.startDevice(appiumArgs);
        let foundBootedDevices = yield mobile_devices_controller_1.DeviceController.getDevices({ platform: mobile_devices_controller_1.Platform.ANDROID, status: mobile_devices_controller_1.Status.BOOTED });
        chai_1.assert.isTrue(foundBootedDevices.some(d => d.token === device.token));
        yield deviceManager.stopDevice(device, appiumArgs);
        foundBootedDevices = yield mobile_devices_controller_1.DeviceController.getDevices({ platform: mobile_devices_controller_1.Platform.ANDROID, status: mobile_devices_controller_1.Status.BOOTED });
        chai_1.assert.isTrue(!foundBootedDevices.some(d => d.token === device.token));
    }));
    it("Start emulator when already started", () => __awaiter(this, void 0, void 0, function* () {
        appiumArgs.extend({ appiumCaps: { platformName: mobile_devices_controller_1.Platform.ANDROID, fullReset: true } });
        const device = yield deviceManager.startDevice(appiumArgs);
        let foundBootedDevices = yield mobile_devices_controller_1.DeviceController.getDevices({ platform: mobile_devices_controller_1.Platform.ANDROID, status: mobile_devices_controller_1.Status.BOOTED });
        chai_1.assert.isTrue(foundBootedDevices.some(d => d.token === device.token));
        yield deviceManager.stopDevice(device, appiumArgs);
        foundBootedDevices = yield mobile_devices_controller_1.DeviceController.getDevices({ platform: mobile_devices_controller_1.Platform.ANDROID, status: mobile_devices_controller_1.Status.BOOTED, token: device.token });
        chai_1.assert.isTrue(!foundBootedDevices || foundBootedDevices.length === 0);
    }));
});
describe("ios devices", () => {
    let deviceManager;
    let appiumArgs;
    before("Init: DeviceManager", () => {
        deviceManager = new device_manager_1.DeviceManager();
        appiumArgs = new ns_capabilities_1.NsCapabilities({});
        appiumArgs.extend({ appiumCaps: { platformName: mobile_devices_controller_1.Platform.IOS, fullReset: false } });
        appiumArgs.shouldSetFullResetOption();
    });
    after("Kill all simulators", () => {
        mobile_devices_controller_1.DeviceController.killAll(mobile_devices_controller_1.DeviceType.SIMULATOR);
    });
    it("Start simulator fullReset: false", () => __awaiter(this, void 0, void 0, function* () {
        const device = yield deviceManager.startDevice(appiumArgs);
        let foundBootedDevices = yield mobile_devices_controller_1.DeviceController.getDevices({ platform: mobile_devices_controller_1.Platform.IOS, status: mobile_devices_controller_1.Status.BOOTED });
        chai_1.assert.isTrue(foundBootedDevices.some(d => d.token === device.token));
        yield deviceManager.stopDevice(device, appiumArgs);
        foundBootedDevices = yield mobile_devices_controller_1.DeviceController.getDevices({ platform: mobile_devices_controller_1.Platform.IOS, status: mobile_devices_controller_1.Status.BOOTED });
        chai_1.assert.isTrue(foundBootedDevices.some(d => d.token === device.token));
    }));
    it("Start simulator fullReset", () => __awaiter(this, void 0, void 0, function* () {
        appiumArgs.extend({ appiumCaps: { platformName: mobile_devices_controller_1.Platform.IOS, fullReset: true } });
        appiumArgs.shouldSetFullResetOption();
        const device = yield deviceManager.startDevice(appiumArgs);
        let foundBootedDevices = yield mobile_devices_controller_1.DeviceController.getDevices({ platform: mobile_devices_controller_1.Platform.IOS, status: mobile_devices_controller_1.Status.BOOTED });
        chai_1.assert.isTrue(foundBootedDevices.some(d => d.token === device.token));
        yield deviceManager.stopDevice(device, appiumArgs);
        foundBootedDevices = yield mobile_devices_controller_1.DeviceController.getDevices({ platform: mobile_devices_controller_1.Platform.IOS, status: mobile_devices_controller_1.Status.BOOTED, token: device.token });
        chai_1.assert.isTrue(!foundBootedDevices || foundBootedDevices.length === 0);
    }));
});
describe("find capabilities", () => __awaiter(this, void 0, void 0, function* () {
    const caps = capabilities_helper_1.resolveCapabilities("../samples", "android23", ".", "appium.capabilities.json");
    chai_1.assert.isTrue(caps.deviceName === "Emulator-Api23-Default");
}));
describe("start Appium server android", () => __awaiter(this, void 0, void 0, function* () {
    before("Init capabilities", () => {
    });
    after("after all ", () => __awaiter(this, void 0, void 0, function* () {
        mobile_devices_controller_1.DeviceController.killAll(mobile_devices_controller_1.DeviceType.EMULATOR);
    }));
    it("Start server", () => __awaiter(this, void 0, void 0, function* () {
        const nsCaps = new ns_capabilities_1.NsCapabilities({
            appPath: androidApp,
            appiumCaps: {
                platformName: mobile_devices_controller_1.Platform.ANDROID,
                fullReset: false
            },
        });
        const server = new appium_server_1.AppiumServer(nsCaps);
        yield server.start(8799);
        chai_1.assert.isTrue(server.hasStarted);
        yield server.stop();
        const startTime = Date.now();
        while (!server.server.killed && Date.now() - startTime < 5000) { }
        chai_1.assert.isTrue(server.server.killed, "Process is not killed");
    }));
    it("Start appium driver", () => __awaiter(this, void 0, void 0, function* () {
        const nsCaps = new ns_capabilities_1.NsCapabilities({
            appPath: androidApp,
            appiumCaps: {
                platformName: mobile_devices_controller_1.Platform.ANDROID,
                fullReset: true
            },
        });
        const server = new appium_server_1.AppiumServer(nsCaps);
        yield server.start(9900);
        chai_1.assert.isTrue(server.hasStarted);
        const driver = yield appium_driver_1.AppiumDriver.createAppiumDriver(server.port, nsCaps);
        const currentWindowName = mobile_devices_controller_1.AndroidController.getCurrentFocusedScreen(nsCaps.device);
        const startTime = Date.now();
        while (!currentWindowName.includes("com.tns.NativeScriptActivity") && Date.now() - startTime < 5000) { }
        chai_1.assert.isTrue(currentWindowName.includes("com.tns.NativeScriptActivity"), `Focused screen doesn't include activity ${currentWindowName}!`);
        yield driver.quit();
        yield server.stop();
    }));
}));
describe("start Appium server ios", () => __awaiter(this, void 0, void 0, function* () {
    before("Init capabilities", () => {
    });
    after("after all ", () => __awaiter(this, void 0, void 0, function* () {
        yield mobile_devices_controller_1.IOSController.killAll();
    }));
    it("Start server", () => __awaiter(this, void 0, void 0, function* () {
        const nsCaps = new ns_capabilities_1.NsCapabilities({
            appPath: iosApp,
            appiumCaps: {
                platformName: mobile_devices_controller_1.Platform.IOS,
                deviceName: "^iPhone 6$",
                platformVersion: "11.2",
                fullReset: false
            },
        });
        const server = new appium_server_1.AppiumServer(nsCaps);
        yield server.start(8799);
        chai_1.assert.isTrue(server.hasStarted);
        yield server.stop();
        const startTime = Date.now();
        while (!server.server.killed && Date.now() - startTime < 5000) { }
        chai_1.assert.isTrue(server.server.killed, "Process is not killed");
    }));
    it("Start appium driver", () => __awaiter(this, void 0, void 0, function* () {
        const nsCaps = new ns_capabilities_1.NsCapabilities({
            appPath: iosApp,
            appiumCaps: {
                platformName: mobile_devices_controller_1.Platform.IOS,
                deviceName: "^iPhone XR$",
                platformVersion: "12",
                fullReset: true
            },
            verbose: false
        });
        const server = new appium_server_1.AppiumServer(nsCaps);
        yield server.start(9900);
        chai_1.assert.isTrue(server.hasStarted);
        const driver = yield appium_driver_1.AppiumDriver.createAppiumDriver(server.port, nsCaps);
        yield driver.quit();
        yield server.stop();
    }));
}));
describe("Start device by apiLevel", () => __awaiter(this, void 0, void 0, function* () {
    it("test-start-emulator-apiLevel-6.0", () => __awaiter(this, void 0, void 0, function* () {
        const nsCaps = index_1.nsCapabilities;
        nsCaps.runType = "android23";
        nsCaps.appPath = androidApp;
        nsCaps.appiumCaps = {
            platformVersion: "6.0",
            platformName: mobile_devices_controller_1.Platform.ANDROID,
            fullReset: true
        };
        const server = yield index_1.startServer();
        const driver = yield index_1.createDriver();
        const currentWindowName = mobile_devices_controller_1.AndroidController.getCurrentFocusedScreen(nsCaps.device);
        const startTime = Date.now();
        while (!currentWindowName.includes("com.tns.NativeScriptActivity") && Date.now() - startTime < 5000) { }
        chai_1.assert.isTrue(currentWindowName.includes("com.tns.NativeScriptActivity"), `Focused screen doesn't include activity ${currentWindowName}!`);
        yield driver.quit();
        yield server.stop();
    }));
    it("test-start-simulator-apiLevel-12.", () => __awaiter(this, void 0, void 0, function* () {
        const nsCaps = index_1.nsCapabilities;
        nsCaps.runType = "android23";
        nsCaps.appPath = iosApp,
            nsCaps.appiumCaps = {
                platformVersion: "12.",
                platformName: mobile_devices_controller_1.Platform.IOS,
                fullReset: true
            };
        const server = yield index_1.startServer();
        const driver = yield index_1.createDriver();
        const apps = mobile_devices_controller_1.IOSController.getInstalledApps(nsCaps.device);
        const isInstalled = apps.some(app => app.includes(nsCaps.appiumCaps.bundleId));
        chai_1.assert.isTrue(isInstalled);
        yield driver.quit();
        yield server.stop();
    }));
}));
//# sourceMappingURL=device-manager.spec.js.map